@@ -526,7 +526,7 @@ def update_application_auth_config(
         auth["redirect_subpath"] = auth_redirect_subpath
 
 
-def update_application_configs(
+def update_application_configs(  # noqa
     config,
     additional_include_user_context_headers=None,
     security_http_cors_allow_resource_origins=None,
@@ -552,6 +552,15 @@ def update_application_configs(
     oidc_config_rewrite_set_cookie=None,
     oidc_config_rewrite_cookie=None,
     client_injection_enabled=None,
+    client_injection_login_type=None,
+    client_injection_login_inject_key_name=None,
+    client_injection_login_fetch_path=None,
+    client_injection_login_detect_login_type=None,
+    client_injection_login_detect_login_fetch_path=None,
+    client_injection_login_form_inject_credentials=None,
+    client_injection_login_form_username_field=None,
+    client_injection_login_form_password_field=None,
+    client_injection_debug=None,
     **kwargs,
 ):
     additional_context = config.setdefault("additional_context", {})
@@ -636,6 +645,56 @@ def update_application_configs(
         client_injection = config.setdefault("client_injection", {})
         client_injection["enabled"] = client_injection_enabled
 
+    def _get_login_config():
+        client_injection = config.setdefault("client_injection", {})
+        return client_injection.setdefault("login_config", {})
+
+    if client_injection_debug is not None:
+        client_injection = config.setdefault("client_injection", {})
+        client_injection["debug"] = client_injection_debug
+
+    if client_injection_login_type:
+        login_config = _get_login_config()
+        login_config["type"] = str(client_injection_login_type)
+
+    if client_injection_login_inject_key_name:
+        login_config = _get_login_config()
+        login_config["inject_key_name"] = client_injection_login_inject_key_name
+
+    if client_injection_login_fetch_path:
+        login_config = _get_login_config()
+        fetch_config = login_config.setdefault("fetch_config", {})
+        fetch_config["paths"] = list(client_injection_login_fetch_path)
+
+    if client_injection_login_detect_login_type:
+        login_config = _get_login_config()
+        logged_in_config = login_config.setdefault("logged_in_config", {})
+        logged_in_config["type"] = str(client_injection_login_detect_login_type)
+
+    if client_injection_login_detect_login_fetch_path:
+        login_config = _get_login_config()
+        logged_in_config = login_config.setdefault("logged_in_config", {})
+        logged_in_config["fetch_path"] = str(
+            client_injection_login_detect_login_fetch_path
+        )
+
+    if client_injection_login_form_inject_credentials is not None:
+        login_config = _get_login_config()
+        form_config = login_config.setdefault("form_config", {})
+        form_config["inject_credentials"] = (
+            client_injection_login_form_inject_credentials
+        )
+
+    if client_injection_login_form_username_field is not None:
+        login_config = _get_login_config()
+        form_config = login_config.setdefault("form_config", {})
+        form_config["username_field"] = client_injection_login_form_username_field
+
+    if client_injection_login_form_password_field is not None:
+        login_config = _get_login_config()
+        form_config = login_config.setdefault("form_config", {})
+        form_config["password_field"] = client_injection_login_form_password_field
+
 
 def update_oidc_standard_headers(
     cfg,
